@@ -3,7 +3,7 @@ package Text::Table::TinyBorderStyle;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2020-06-11'; # DATE
 our $DIST = 'Text-Table-TinyBorderStyle'; # DIST
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 use 5.006;
 use strict;
@@ -19,7 +19,11 @@ sub generate_table {
     my %params = @_;
     my $rows = $params{rows} or die "Must provide rows!";
 
-    my $border_style_name = $params{border_style} || 'BorderStyle::ASCII::SingleLine';
+    my $border_style_name = $params{border_style} ||
+        $ENV{TEXT_TABLE_TINY_BORDER_STYLE} ||
+        $ENV{BORDER_STYLE} ||
+        'BorderStyle::ASCII::SingleLine';
+
     require Module::Load::Util;
     my $border_style_obj = Module::Load::Util::instantiate_class_with_optional_args($border_style_name);
 
@@ -173,7 +177,7 @@ Text::Table::TinyBorderStyle - Text::Table::Tiny + support for colored text
 
 =head1 VERSION
 
-This document describes version 0.002 of Text::Table::TinyBorderStyle (from Perl distribution Text-Table-TinyBorderStyle), released on 2020-06-11.
+This document describes version 0.003 of Text::Table::TinyBorderStyle (from Perl distribution Text-Table-TinyBorderStyle), released on 2020-06-11.
 
 =head1 SYNOPSIS
 
@@ -200,6 +204,18 @@ Interface, options, and format variables are the same as in Text::Table::Tiny.
 
 =for Pod::Coverage ^(.+)$
 
+=head1 ENVIRONMENT
+
+=head2 BORDER_STYLE
+
+Set default for C<border_style> argument. See also
+L</TEXT_TABLE_TINY_BORDER_STYLE>.
+
+=head2 BORDER_STYLE
+
+Set default for C<border_style> argument. Takes precedence over
+L</BORDER_STYLE>.
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Text-Table-TinyBorderStyle>.
